@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention App Center
 #  univention-app module for getting log output from a docker app
@@ -58,5 +57,5 @@ class Logs(UniventionAppAction, DockerActionMixin):
 
     def show_docker_logs(self, args):
         docker = self._get_docker(args.app)
-        self.log("#### 'docker logs {}' output:".format(docker.container))
+        self.log(f"#### 'docker logs {docker.container}' output:")
         return subprocess.call(['docker', 'logs', docker.container])
