@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention App Center
 #  univention-app module for updating the list of available apps
@@ -39,9 +38,9 @@ import os
 import os.path
 import zlib
 from argparse import SUPPRESS, ArgumentParser, Namespace  # noqa: F401
+from collections.abc import Iterable, Iterator, Mapping  # noqa: F401
 from glob import glob
 from gzip import open as gzip_open
-from typing import Dict, Iterable, Iterator, List, Mapping, Optional  # noqa: F401
 from urllib.error import HTTPError
 from urllib.request import Request
 
