@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention App Center
 #  module for storing Apps in a cache
@@ -39,12 +38,12 @@
 import os
 import os.path
 import sys
+from collections.abc import Iterable  # noqa: F401
 from configparser import NoSectionError
 from contextlib import contextmanager
 from glob import glob
 from json import dump, load
 from time import sleep
-from typing import Dict, Iterable, List, Optional, Tuple  # noqa: F401
 from urllib.parse import urlsplit
 
 from univention.appcenter.app import App, LooseVersion
@@ -63,12 +62,12 @@ cache_logger = get_base_logger().getChild('cache')
 
 def _cmp_mtimes(mtime1, mtime2):
     # type: (Optional[float], Optional[float]) -> int
-    mtime1 = float('{:.3f}'.format(mtime1)) if mtime1 is not None else 0.0
-    mtime2 = float('{:.3f}'.format(mtime2)) if mtime2 is not None else 0.0
+    mtime1 = float(f'{mtime1:.3f}') if mtime1 is not None else 0.0
+    mtime2 = float(f'{mtime2:.3f}') if mtime2 is not None else 0.0
     return 0 if mtime1 == mtime2 else (-1 if mtime1 < mtime2 else 1)
 
 
-class _AppCache(object):
+class _AppCache:
     def get_every_single_app(self):
         # type: () -> Iterable[App]
         raise NotImplementedError()
@@ -452,6 +451,11 @@ class AppCenterCache(_AppCache):
             ucs_version = self._get_current_ucs_version()
             cache_file = self.get_cache_file('.ucs.ini')
             self._ucs_versions = _get_ucs_versions_for(ucs_version, cache_file) or [ucs_version]
+        # TODO always appending "5.0" is a workaround for now. We need a way to fetch data from .ucs.ini even
+        # in situations where the system cannot connect to the internet. A pre-installed version of .ucs.ini
+        # that we can fall back to in "offline mode" is needed.. (same way we do it with the all.tar.gz file)
+        if "5.0" not in self._ucs_versions:
+            self._ucs_versions.append("5.0")
         return self._ucs_versions
 
     def get_locale(self):
