@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  module: software management
@@ -34,7 +33,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-import json
 import locale
 import logging
 import os
@@ -83,7 +81,7 @@ from .util import ComponentManager, create_url, install_opener, scheme_is_http,
 _ = umc.Translation('univention-management-console-module-appcenter').translate
 
 
-class NoneCandidate(object):
+class NoneCandidate:
     """
     Mock object if package has no candidate
     (may happen without network connection)
@@ -96,7 +94,7 @@ class NoneCandidate(object):
 
 class UMCProgressHandler(logging.Handler):
     def __init__(self, progress):
-        super(UMCProgressHandler, self).__init__()
+        super().__init__()
         self.progress = progress
 
     def emit(self, record):
@@ -109,7 +107,7 @@ class UMCProgressHandler(logging.Handler):
 
 class ProgressInfoHandler(logging.Handler):
     def __init__(self, package_manager):
-        super(ProgressInfoHandler, self).__init__()
+        super().__init__()
         self.state = package_manager.progress_state
 
     def emit(self, record):
@@ -198,7 +196,7 @@ class Instance(umcm.Base, ProgressMixin):
 
     def error_handling(self, etype, exc, etraceback):
         error_handling(etype, exc, etraceback)
-        return super(Instance, self).error_handling(exc, etype, etraceback)
+        return super().error_handling(exc, etype, etraceback)
 
     @simple_response
     def version(self, version=None):
@@ -378,27 +376,16 @@ class Instance(umcm.Base, ProgressMixin):
 
     @simple_response
     def query(self, quick=False):
-        query_cache_file = '/var/cache/univention-appcenter/umc-query.json'
+        cache = get_action('umc-generate-app-cache')
         if quick:
-            try:
-                with open(query_cache_file) as fd:
-                    return json.load(fd)
-            except (OSError, ValueError) as exc:
-                MODULE.error('Error returning cached query: %s' % exc)
-                return []
+            return cache.load()
         self.update_applications()
         self.ucr.load()
         reload_package_manager()
-        list_apps = get_action('list')
-        domain = get_action('domain')
-        apps = list_apps.get_apps()
         if self.ucr.is_true('appcenter/docker', True):
             if not self._test_for_docker_service():
                 raise umcm.UMC_Error(_('The docker service is not running! The App Center will not work properly.') + ' ' + _('Make sure docker.io is installed, try starting the service with "service docker start".'))
-        info = domain.to_dict(apps)
-        with open(query_cache_file, 'w') as fd:
-            json.dump(info, fd)
-        return info
+        return cache.generate()
 
     def update_applications(self):
         if self.ucr.is_true('appcenter/umc/update/always', True):
